"""REST API service for read-only database exposure.

See Also:
    [Api][bigbrotr.services.api.service.Api]: The service class.
    [ApiConfig][bigbrotr.services.api.service.ApiConfig]: Service configuration.
"""

from .service import Api, ApiConfig


__all__ = ["Api", "ApiConfig"]
